#!/usr/bin/perl
require "$ENV{FT_DIR}/bin/ftcutils.pl";

# Check configuration
exists($ENV{FT_DIR}) or 
  die "FT_DIR environment variable not set.  Exiting.\n";
exists($ENV{FT_DOMAIN}) or 
  die "FT_DOMAIN environment variable not set.  Exiting.\n";
exists($ENV{FT_LOG_DIR}) or
  die "FT_LOG_DIR environment variable not set.  Exiting.\n";
exists($ENV{FT_CONFIG_DIR}) or
  die "FT_CONFIG_DIR environment variable not set.  Exiting.\n";
exists($ENV{LD_LIBRARY_PATH}) or
  die "LD_LIBRARY_PATH environment variable not set.  Exiting.\n";

# Declarations
my $deffile = "$ENV{FT_DIR}/ha/vmap.def";

# Read in the file
open(IN,"<$deffile") or die "Cannot open def file!";
my $lines = "";
while ( <IN> )     {
    $lines .= $_;
}
close IN;

my $hostname = &get_local_hostname();
if ($hostname eq "") {
    die "Cannot identify host, make sure host name is configured";
}

$lines =~ s/\<NodeName\>/$hostname/g;
$lines =~ s/\<FT_DIR\>/$ENV{FT_DIR}/g;
$lines =~ s/\<FT_LOG_DIR\>/$ENV{FT_LOG_DIR}/g;	

# Write out the new def file
my $tempdef = "$ENV{FT_DIR}/bin/vm_temp.def";

open( MYFILE, "> $tempdef") ||
    die "Cannot create file $config_import_file \n$!";
print MYFILE "$lines";
close MYFILE;

# Import the definition file
my $cmd = "$ENV{FT_DIR}/bin/ftcli -cmd \"import $tempdef -skipfail=false\"";
my $res = &issue_cli_command($cmd);
print $cmd . "\n";
print $res . "\n";

# Wake up the rule to have it recalculate the number of primaries
$cmd = "$ENV{FT_DIR}/bin/ftcli -cmd \"fireondemandtrigger NodeDeleted on 1 0\"";
my $res = &issue_cli_command($cmd);
print $cmd . "\n";
print $res . "\n";

$cmd = "$ENV{FT_DIR}/bin/ftcli -cmd \"addNodeAttr $hostname ConfigurationStatus complete\"";
$res = &issue_cli_command($cmd);
print $cmd . "\n";
print $res . "\n";


sub issue_cli_command {
   my $command = shift;
   my $res = `$command`;
   
   while (($res =~ "connection between the user and the|a proxy") ||
          ($res =~ "Receiver Did Not Respond") ||
          ($res =~ "No AAM Primary Agents")) {
      # The agent may be restarting, try again 
      my $retries = 3;
      print "Failed to run $command\n";
      print "Retrying command again...\n";
      sleep(3); # give the agent a change to restart
      $res = `$command`;
   }
   return $res;
}







